==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageRegistryConfigStorageBuilder extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageBuilder>{
  public ImageRegistryConfigStorageBuilder() {
    this(false);
  }
  public ImageRegistryConfigStorageBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageRegistryConfigStorage(), validationEnabled);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageRegistryConfigStorage(), validationEnabled);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAzure(instance.getAzure()); 
    fluent.withEmptyDir(instance.getEmptyDir()); 
    fluent.withGcs(instance.getGcs()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withPvc(instance.getPvc()); 
    fluent.withS3(instance.getS3()); 
    fluent.withSwift(instance.getSwift()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance) {
    this(instance,false);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAzure(instance.getAzure()); 
    this.withEmptyDir(instance.getEmptyDir()); 
    this.withGcs(instance.getGcs()); 
    this.withManagementState(instance.getManagementState()); 
    this.withPvc(instance.getPvc()); 
    this.withS3(instance.getS3()); 
    this.withSwift(instance.getSwift()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage build() {
    ImageRegistryConfigStorage buildable = new ImageRegistryConfigStorage(fluent.getAzure(),fluent.getEmptyDir(),fluent.getGcs(),fluent.getManagementState(),fluent.getPvc(),fluent.getS3(),fluent.getSwift());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageBuilder that = (ImageRegistryConfigStorageBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageRegistryConfigStorageBuilder extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageBuilder>{
  public ImageRegistryConfigStorageBuilder() {
    this(false);
  }
  public ImageRegistryConfigStorageBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageRegistryConfigStorage(), validationEnabled);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageRegistryConfigStorage(), validationEnabled);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance) {
    this(fluent, instance, false);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAzure(instance.getAzure()); 
    fluent.withEmptyDir(instance.getEmptyDir()); 
    fluent.withGcs(instance.getGcs()); 
    fluent.withIbmcos(instance.getIbmcos()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withPvc(instance.getPvc()); 
    fluent.withS3(instance.getS3()); 
    fluent.withSwift(instance.getSwift()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance) {
    this(instance,false);
  }
  public ImageRegistryConfigStorageBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAzure(instance.getAzure()); 
    this.withEmptyDir(instance.getEmptyDir()); 
    this.withGcs(instance.getGcs()); 
    this.withIbmcos(instance.getIbmcos()); 
    this.withManagementState(instance.getManagementState()); 
    this.withPvc(instance.getPvc()); 
    this.withS3(instance.getS3()); 
    this.withSwift(instance.getSwift()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorageFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigStorage build() {
    ImageRegistryConfigStorage buildable = new ImageRegistryConfigStorage(fluent.getAzure(),fluent.getEmptyDir(),fluent.getGcs(),fluent.getIbmcos(),fluent.getManagementState(),fluent.getPvc(),fluent.getS3(),fluent.getSwift());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageBuilder that = (ImageRegistryConfigStorageBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
